@@ -13,37 +13,21 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_config import cfg
-from oslo_log import log as logging
 from paste import deploy
-
+from designate.openstack.common import log as logging
+from designate.openstack.deprecated import wsgi
+from oslo.config import cfg
 from designate import exceptions
-from designate import service
 from designate import utils
+from designate import policy
+
 
 LOG = logging.getLogger(__name__)
 
 
-class Service(service.WSGIService):
-    def __init__(self):
-        super(Service, self).__init__(
-            self.wsgi_application,
-            self.service_name,
-            cfg.CONF['service:api'].listen,
-        )
+class Service(wsgi.Service):
+    def __init__(self, backlog=128, threads=1000):
 
-    def start(self):
-        super(Service, self).start()
-
-    def stop(self, graceful=True):
-        super(Service, self).stop(graceful)
-
-    @property
-    def service_name(self):
-        return 'api'
-
-    @property
-    def wsgi_application(self):
         api_paste_config = cfg.CONF['service:api'].api_paste_config
         config_paths = utils.find_config(api_paste_config)
 
@@ -51,6 +35,15 @@ class Service(service.WSGIService):
             msg = 'Unable to determine appropriate api-paste-config file'
             raise exceptions.ConfigurationError(msg)
 
-        LOG.info('Using api-paste-config found at: %s', config_paths[0])
+        LOG.info('Using api-paste-config found at: %s' % config_paths[0])
 
-        return deploy.loadapp("config:%s" % config_paths[0], name='osapi_dns')
+        policy.init_policy()
+
+        application = deploy.loadapp("config:%s" % config_paths[0],
+                                     name='osapi_dns')
+
+        super(Service, self).__init__(application=application,
+                                      host=cfg.CONF['service:api'].api_host,
+                                      port=cfg.CONF['service:api'].api_port,
+                                      backlog=backlog,
+                                      threads=threads)
