@@ -1,6 +1,6 @@
 # Copyright 2012 Hewlett-Packard Development Company, L.P. All Rights Reserved.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -14,21 +14,23 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import flask
-import oslo_messaging as messaging
-
-from designate import rpc
-
+from designate.openstack.common import log as logging
+from designate.openstack.common import rpc
 
+LOG = logging.getLogger(__name__)
 blueprint = flask.Blueprint('diagnostics', __name__)
 
 
 @blueprint.route('/diagnostics/ping/<topic>/<host>', methods=['GET'])
 def ping_host(topic, host):
     context = flask.request.environ.get('context')
+    queue = rpc.queue_get_for(context, topic, host)
 
-    client = rpc.get_client(messaging.Target(topic=topic))
-    cctxt = client.prepare(server=host, timeout=10)
+    msg = {
+        'method': 'ping',
+        'args': {},
+    }
 
-    pong = cctxt.call(context, 'ping')
+    pong = rpc.call(context, queue, msg, timeout=10)
 
     return flask.jsonify(pong)
