@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -13,18 +13,16 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_log import log as logging
+from designate.api.v2 import patches  # flake8: noqa
 import pecan.deploy
+from oslo.config import cfg
+from designate.openstack.common import log as logging
 
-import designate.conf
-
-
-CONF = designate.conf.CONF
 LOG = logging.getLogger(__name__)
 
 
 def factory(global_config, **local_conf):
-    if not CONF['service:api'].enable_api_v2:
+    if not cfg.CONF['service:api'].enable_api_v2:
         def disabled_app(environ, start_response):
             status = '404 Not Found'
             start_response(status, [])
@@ -35,12 +33,7 @@ def factory(global_config, **local_conf):
     conf = {
         'app': {
             'root': 'designate.api.v2.controllers.root.RootController',
-            'modules': ['designate.api.v2'],
-            'errors': {
-                404: '/errors/not_found',
-                405: '/errors/method_not_allowed',
-                '__force_dict__': True
-            }
+            'modules': ['designate.api.v2']
         }
     }
 
