@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -15,18 +15,21 @@
 # under the License.
 import pecan
 import pecan.deploy
+from oslo.config import cfg
+from designate.openstack.common import log as logging
 
-from designate.api.v2 import patches
-import designate.conf
+LOG = logging.getLogger(__name__)
 
-
-CONF = designate.conf.CONF
+cfg.CONF.register_opts([
+    cfg.BoolOpt('pecan_debug', default=False,
+                help='Pecan HTML Debug Interface'),
+], group='service:api')
 
 
 def setup_app(pecan_config):
     config = dict(pecan_config)
 
-    config['app']['debug'] = CONF['service:api'].pecan_debug
+    config['app']['debug'] = cfg.CONF['service:api'].pecan_debug
 
     pecan.configuration.set_config(config, overwrite=True)
 
@@ -34,8 +37,6 @@ def setup_app(pecan_config):
         pecan_config.app.root,
         debug=getattr(pecan_config.app, 'debug', False),
         force_canonical=getattr(pecan_config.app, 'force_canonical', True),
-        request_cls=patches.Request,
-        guess_content_type_from_ext=False
     )
 
     return app
