@@ -13,124 +13,124 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_log import log as logging
+
 import pecan
-
-from designate.api.v2.controllers import rest
-from designate.objects.adapters import DesignateAdapter
-from designate.objects import Blacklist
+from designate.central import rpcapi as central_rpcapi
+from designate.openstack.common import log as logging
+from designate import schema
 from designate import utils
-
+from designate.api.v2.controllers import rest
+from designate.api.v2.views import blacklists as blacklists_view
 
 LOG = logging.getLogger(__name__)
+central_api = central_rpcapi.CentralAPI()
 
 
 class BlacklistsController(rest.RestController):
+    _view = blacklists_view.BlacklistsView()
+    _resource_schema = schema.Schema('v2', 'blacklist')
+    _collection_schema = schema.Schema('v2', 'blacklists')
     SORT_KEYS = ['created_at', 'id', 'updated_at', 'pattern']
 
     @pecan.expose(template='json:', content_type='application/json')
     @utils.validate_uuid('blacklist_id')
     def get_one(self, blacklist_id):
-        """Get Blacklist"""
+        """ Get Blacklist """
 
         request = pecan.request
         context = request.environ['context']
 
-        blacklist = self.central_api.get_blacklist(context, blacklist_id)
+        blacklist = central_api.get_blacklist(context, blacklist_id)
 
-        LOG.info("Retrieved %(blacklist)s", {'blacklist': blacklist})
-
-        return DesignateAdapter.render('API_v2', blacklist, request=request)
+        return self._view.show(context, request, blacklist)
 
     @pecan.expose(template='json:', content_type='application/json')
     def get_all(self, **params):
-        """List all Blacklisted Zones"""
+        """ List all Blacklisted Zones """
         request = pecan.request
         context = request.environ['context']
 
         # Extract the pagination params
-        marker, limit, sort_key, sort_dir = utils.get_paging_params(
-                context, params, self.SORT_KEYS)
+        marker, limit, sort_key, sort_dir = self._get_paging_params(params)
 
         # Extract any filter params
-        accepted_filters = ('pattern', )
-        criterion = self._apply_filter_params(
-            params, accepted_filters, {})
+        accepted_filters = ('pattern')
+        criterion = dict((k, params[k]) for k in accepted_filters
+                         if k in params)
 
-        blacklists = self.central_api.find_blacklists(
+        blacklist = central_api.find_blacklists(
             context, criterion, marker, limit, sort_key, sort_dir)
 
-        LOG.info("Retrieved %(blacklists)s", {'blacklists': blacklists})
-
-        return DesignateAdapter.render('API_v2', blacklists, request=request)
+        return self._view.list(context, request, blacklist)
 
     @pecan.expose(template='json:', content_type='application/json')
     def post_all(self):
-        """Create Blacklisted Zone"""
+        """ Create Blacklisted Zone """
         request = pecan.request
         response = pecan.response
         context = request.environ['context']
+
         body = request.body_dict
 
-        blacklist = DesignateAdapter.parse('API_v2', body, Blacklist())
+        # Validate the request conforms to the schema
+        self._resource_schema.validate(body)
 
-        blacklist.validate()
+        # Convert from APIv2 -> Central format
+        values = self._view.load(context, request, body)
 
         # Create the blacklist
-        blacklist = self.central_api.create_blacklist(
-            context, blacklist)
-
-        LOG.info("Created %(blacklist)s", {'blacklist': blacklist})
+        blacklist = central_api.create_blacklist(context, values)
 
         response.status_int = 201
 
-        blacklist = DesignateAdapter.render('API_v2', blacklist,
-                                            request=request)
-
-        response.headers['Location'] = blacklist['links']['self']
+        response.headers['Location'] = self._view._get_resource_href(
+            request, blacklist)
 
         # Prepare and return the response body
-        return blacklist
+        return self._view.show(context, request, blacklist)
 
     @pecan.expose(template='json:', content_type='application/json')
     @pecan.expose(template='json:', content_type='application/json-patch+json')
     @utils.validate_uuid('blacklist_id')
     def patch_one(self, blacklist_id):
-        """Update Blacklisted Zone"""
+        """ Update Blacklisted Zone """
         request = pecan.request
         context = request.environ['context']
         body = request.body_dict
         response = pecan.response
 
+        # Fetch the existing blacklisted zone
+        blacklist = central_api.get_blacklist(context, blacklist_id)
+
+        # Convert to APIv2 Format
+        blacklist = self._view.show(context, request, blacklist)
+
         if request.content_type == 'application/json-patch+json':
-            raise NotImplementedError('json-patch not implemented')
+            raise NotImplemented('json-patch not implemented')
+        else:
+            blacklist = utils.deep_dict_merge(blacklist, body)
 
-        # Fetch the existing blacklist entry
-        blacklist = self.central_api.get_blacklist(context, blacklist_id)
+            # Validate the request conforms to the schema
+            self._resource_schema.validate(blacklist)
 
-        blacklist = DesignateAdapter.parse('API_v2', body, blacklist)
+            values = self._view.load(context, request, body)
 
-        blacklist.validate()
-
-        blacklist = self.central_api.update_blacklist(context, blacklist)
-
-        LOG.info("Updated %(blacklist)s", {'blacklist': blacklist})
+            blacklist = central_api.update_blacklist(context,
+                                                     blacklist_id, values)
 
         response.status_int = 200
 
-        return DesignateAdapter.render('API_v2', blacklist, request=request)
+        return self._view.show(context, request, blacklist)
 
     @pecan.expose(template=None, content_type='application/json')
     @utils.validate_uuid('blacklist_id')
     def delete_one(self, blacklist_id):
-        """Delete Blacklisted Zone"""
+        """ Delete Blacklisted Zone """
         request = pecan.request
         response = pecan.response
         context = request.environ['context']
 
-        blacklist = self.central_api.delete_blacklist(context, blacklist_id)
-
-        LOG.info("Deleted %(blacklist)s", {'blacklist': blacklist})
+        central_api.delete_blacklist(context, blacklist_id)
 
         response.status_int = 204
 
