@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Endre Karlson <endre.karlson@hpe.com>
+# Author: Endre Karlson <endre.karlson@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -13,17 +13,17 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import re
-
-from oslo_log import log as logging
 import pecan
-
-from designate.api.v2.controllers import rest
+import re
 from designate import exceptions
-from designate import objects
-from designate.objects.adapters import DesignateAdapter
+from designate import schema
+from designate.api.v2.controllers import rest
+from designate.api.v2.views import floatingips as floatingips_views
+from designate.central import rpcapi as central_rpcapi
+
+
+central_api = central_rpcapi.CentralAPI()
 
-LOG = logging.getLogger(__name__)
 
 FIP_REGEX = '^(?P<region>[A-Za-z0-9\\.\\-_]{1,100}):' \
             '(?P<id>[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-' \
@@ -42,18 +42,18 @@ def fip_key_to_data(key):
 
 
 class FloatingIPController(rest.RestController):
+    _view = floatingips_views.FloatingIPView()
+    _resource_schema = schema.Schema('v2', 'floatingip')
+    _collection_schema = schema.Schema('v2', 'floatingips')
 
     @pecan.expose(template='json:', content_type='application/json')
     def get_all(self, **params):
-        """List Floating IP PTRs for a Tenant"""
+        """ List Floating IP PTRs for a Tenant """
         request = pecan.request
         context = request.environ['context']
 
-        fips = self.central_api.list_floatingips(context)
-
-        LOG.info("Retrieved %(fips)s", {'fips': fips})
-
-        return DesignateAdapter.render('API_v2', fips, request=request)
+        fips = central_api.list_floatingips(context)
+        return self._view.list(context, request, fips)
 
     @pecan.expose(template='json:', content_type='application/json')
     def patch_one(self, fip_key):
@@ -61,32 +61,19 @@ class FloatingIPController(rest.RestController):
         Set or unset a PTR
         """
         request = pecan.request
-        response = pecan.response
-
         context = request.environ['context']
-        try:
-            body = request.body_dict
-        except Exception as e:
-            if str(e) != 'TODO: Unsupported Content Type':
-                raise
-            else:
-                # Got a blank body
-                body = dict()
+        body = request.body_dict
 
         region, id_ = fip_key_to_data(fip_key)
 
-        fip = DesignateAdapter.parse('API_v2', body, objects.FloatingIP())
+        # Validate the request conforms to the schema
+        self._resource_schema.validate(body)
 
-        fip.validate()
-
-        LOG.info("Updated %(fip)s", {'fip': fip})
-
-        fip = self.central_api.update_floatingip(context, region, id_, fip)
-
-        response.status_int = 202
+        fip = central_api.update_floatingip(
+            context, region, id_, body['floatingip'])
 
         if fip:
-            return DesignateAdapter.render('API_v2', fip, request=request)
+            return self._view.show(context, request, fip)
 
     @pecan.expose(template='json:', content_type='application/json')
     def get_one(self, fip_key):
@@ -98,8 +85,6 @@ class FloatingIPController(rest.RestController):
 
         region, id_ = fip_key_to_data(fip_key)
 
-        fip = self.central_api.get_floatingip(context, region, id_)
+        fip = central_api.get_floatingip(context, region, id_)
 
-        LOG.info("Retrieved %(fip)s", {'fip': fip})
-
-        return DesignateAdapter.render('API_v2', fip, request=request)
+        return self._view.show(context, request, fip)
