@@ -24,16 +24,16 @@
 # ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-
+import six
 import inspect
-
 import pecan
 import pecan.rest
 import pecan.routing
-
 from designate import exceptions
-from designate.central import rpcapi as central_rpcapi
+from designate.openstack.common import log as logging
+from designate.openstack.common.gettextutils import _
+
+LOG = logging.getLogger(__name__)
 
 
 class RestController(pecan.rest.RestController):
@@ -47,39 +47,48 @@ class RestController(pecan.rest.RestController):
     # default sort_keys.  The Controllers can override this.
     SORT_KEYS = ['created_at', 'id']
 
-    @property
-    def central_api(self):
-        return central_rpcapi.CentralAPI.get_instance()
-
-    @classmethod
-    def _apply_filter_params(cls, params, accepted_filters, criterion):
-        duplicate = []
-        invalid = []
-
-        for k in params:
-            if isinstance(params[k], list):
-                duplicate.append(k)
-                continue
-
-            if k in accepted_filters:
-                criterion[k] = params[k].replace("*", "%")
-            else:
-                invalid.append(k)
-
-        if duplicate:
-            raise exceptions.BadRequest(
-                'Duplicate filters %s' % ', '.join(duplicate))
-
-        if invalid:
-            raise exceptions.BadRequest(
-                'Invalid filters %s' % ', '.join(invalid))
-
-        return criterion
-
-    def _handle_post(self, method, remainder, request=None):
+    def _get_paging_params(self, params):
         """
+        Extract any paging parameters
+        """
+        marker = params.pop('marker', None)
+        limit = params.pop('limit', None)
+        sort_key = params.pop('sort_key', None)
+        sort_dir = params.pop('sort_dir', None)
+
+        # Negative and zero limits are not caught in storage.
+        # With a number bigger than MAXSIZE, rpc throws an 'OverflowError long
+        #  too big to convert'.
+        # So the parameter 'limit' is checked here.
+        if limit:
+            try:
+                invalid_limit_message = _(str.format(
+                    'limit should be an integer between 1 and {0}',
+                    six.MAXSIZE))
+                int_limit = int(limit)
+                if int_limit <= 0 or int_limit > six.MAXSIZE:
+                    raise exceptions.InvalidLimit(invalid_limit_message)
+            # This exception is raised for non ints when int(limit) is called
+            except ValueError:
+                raise exceptions.InvalidLimit(invalid_limit_message)
+
+        # sort_dir is checked in paginate_query.
+        # We duplicate the sort_dir check here to throw a more specific
+        # exception than ValueError.
+        if sort_dir and sort_dir not in ['asc', 'desc']:
+            raise exceptions.InvalidSortDir(_("Unknown sort direction, "
+                                              "must be 'desc' or 'asc'"))
+
+        if sort_key and sort_key not in self.SORT_KEYS:
+            raise exceptions.InvalidSortKey(_(str.format(
+                'sort key must be one of {0}', str(self.SORT_KEYS))))
+
+        return marker, limit, sort_key, sort_dir
+
+    def _handle_post(self, method, remainder):
+        '''
         Routes ``POST`` actions to the appropriate controller.
-        """
+        '''
         # route to a post_all or get if no additional parts are available
         if not remainder or remainder == ['']:
             controller = self._find_controller('post_all', 'post')
@@ -89,8 +98,7 @@ class RestController(pecan.rest.RestController):
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
-            return pecan.routing.lookup_controller(controller, remainder[1:],
-                                                   request=request)
+            return pecan.routing.lookup_controller(controller, remainder[1:])
 
         # finally, check for the regular post_one/post requests
         controller = self._find_controller('post_one', 'post')
@@ -99,10 +107,10 @@ class RestController(pecan.rest.RestController):
 
         pecan.abort(405)
 
-    def _handle_patch(self, method, remainder, request=None):
-        """
+    def _handle_patch(self, method, remainder):
+        '''
         Routes ``PATCH`` actions to the appropriate controller.
-        """
+        '''
         # route to a patch_all or get if no additional parts are available
         if not remainder or remainder == ['']:
             controller = self._find_controller('patch_all', 'patch')
@@ -112,8 +120,7 @@ class RestController(pecan.rest.RestController):
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
-            return pecan.routing.lookup_controller(controller, remainder[1:],
-                                                   request=request)
+            return pecan.routing.lookup_controller(controller, remainder[1:])
 
         # finally, check for the regular patch_one/patch requests
         controller = self._find_controller('patch_one', 'patch')
@@ -122,10 +129,10 @@ class RestController(pecan.rest.RestController):
 
         pecan.abort(405)
 
-    def _handle_put(self, method, remainder, request=None):
-        """
+    def _handle_put(self, method, remainder):
+        '''
         Routes ``PUT`` actions to the appropriate controller.
-        """
+        '''
         # route to a put_all or get if no additional parts are available
         if not remainder or remainder == ['']:
             controller = self._find_controller('put_all', 'put')
@@ -135,8 +142,7 @@ class RestController(pecan.rest.RestController):
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
-            return pecan.routing.lookup_controller(controller, remainder[1:],
-                                                   request=request)
+            return pecan.routing.lookup_controller(controller, remainder[1:])
 
         # finally, check for the regular put_one/put requests
         controller = self._find_controller('put_one', 'put')
@@ -145,10 +151,10 @@ class RestController(pecan.rest.RestController):
 
         pecan.abort(405)
 
-    def _handle_delete(self, method, remainder, request=None):
-        """
+    def _handle_delete(self, method, remainder):
+        '''
         Routes ``DELETE`` actions to the appropriate controller.
-        """
+        '''
         # route to a delete_all or get if no additional parts are available
         if not remainder or remainder == ['']:
             controller = self._find_controller('delete_all', 'delete')
@@ -158,8 +164,7 @@ class RestController(pecan.rest.RestController):
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
-            return pecan.routing.lookup_controller(controller, remainder[1:],
-                                                   request=request)
+            return pecan.routing.lookup_controller(controller, remainder[1:])
 
         # finally, check for the regular delete_one/delete requests
         controller = self._find_controller('delete_one', 'delete')
