@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -13,10 +13,9 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_serialization import jsonutils
 import pecan.core
-
 from designate import exceptions
+from designate.openstack.common import jsonutils
 
 JSON_TYPES = ('application/json', 'application/json-patch+json')
 
@@ -25,24 +24,19 @@ class Request(pecan.core.Request):
     @property
     def body_dict(self):
         """
-        Returns the body content as a dictionary, deserializing per the
+        Returns the body content as a dictonary, deserializing per the
         Content-Type header.
 
         We add this method to ease future XML support, so the main code
-        is not hardcoded to call pecans "request.json" method.
+        is not hardcoded to call pecans "request.json()" method.
         """
-        if self.content_type not in JSON_TYPES:
-            raise exceptions.UnsupportedContentType(
-                'Content-type must be application/json')
+        if self.content_type in JSON_TYPES:
+            try:
+                return jsonutils.load(self.body_file)
+            except ValueError as valueError:
+                raise exceptions.InvalidJson(valueError.message)
+        else:
+            raise Exception('TODO: Unsupported Content Type')
 
-        try:
-            json_dict = jsonutils.load(self.body_file)
-            if json_dict is None:
-                # NOTE(kiall): Somehow, json.load(fp) is returning None.
-                raise exceptions.EmptyRequestBody('Request Body is empty')
-            return json_dict
-        except ValueError as e:
-            if not self.body:
-                raise exceptions.EmptyRequestBody('Request Body is empty')
-            else:
-                raise exceptions.InvalidJson(str(e))
+
+pecan.core.Request = Request
