@@ -13,27 +13,15 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_log import log as logging
-
-from designate.backend import base
+from designate.openstack.common import log as logging
+from designate.backend.base import Backend
 
 LOG = logging.getLogger(__name__)
 
-GOOD_STATUSES = [
-    'integrated', 'grades.master-compatible', 'release-compatible'
-]
 
+def get_backend(backend_driver, central_service):
+    LOG.debug("Loading backend driver: %s" % backend_driver)
 
-def get_backend(target):
-    cls = base.Backend.get_driver(target.type)
+    cls = Backend.get_driver(backend_driver)
 
-    message = "Backend Driver '{}' loaded. Has status of '{}'".format(
-        target.type, cls.__backend_status__
-    )
-
-    if cls.__backend_status__ in GOOD_STATUSES:
-        LOG.info(message)
-    else:
-        LOG.warning(message)
-
-    return cls(target)
+    return cls(central_service=central_service)
