@@ -1,6 +1,6 @@
-# Copyright 2014 Rackspace Inc.
+# Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Tim Simmons <tim.simmons@rackspace.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -14,29 +14,19 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import sys
-
-from oslo_log import log as logging
-from oslo_reports import guru_meditation_report as gmr
-
-from designate.agent import service as agent_service
-import designate.conf
-from designate import heartbeat_emitter
-from designate import service
+from oslo.config import cfg
+from designate.openstack.common import log as logging
+from designate.openstack.common import service
 from designate import utils
-from designate import version
+from designate.agent import service as agent_service
 
-
-CONF = designate.conf.CONF
+CONF = cfg.CONF
 CONF.import_opt('workers', 'designate.agent', group='service:agent')
 
 
 def main():
     utils.read_config('designate', sys.argv)
-    logging.setup(CONF, 'designate')
-    gmr.TextGuruMeditation.setup_autorun(version)
-
-    server = agent_service.Service()
-    heartbeat = heartbeat_emitter.get_heartbeat_emitter(server.service_name)
-    service.serve(server, workers=CONF['service:agent'].workers)
-    heartbeat.start()
-    service.wait()
+    logging.setup('designate')
+    launcher = service.launch(agent_service.Service(),
+                              CONF['service:agent'].workers)
+    launcher.wait()
