@@ -13,24 +13,34 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_log import log as logging
+from oslo.config import cfg
+from designate.openstack.common import log as logging
+from designate.notification_handler.base import BaseAddressHandler
 
-import designate.conf
-from designate.notification_handler import base
-
-
-CONF = designate.conf.CONF
 LOG = logging.getLogger(__name__)
 
+cfg.CONF.register_group(cfg.OptGroup(
+    name='handler:neutron_floatingip',
+    title="Configuration for Neutron Notification Handler"
+))
 
-class NeutronFloatingHandler(base.BaseAddressHandler):
-    """Handler for Neutron's notifications"""
+cfg.CONF.register_opts([
+    cfg.ListOpt('notification-topics', default=['monitor']),
+    cfg.StrOpt('control-exchange', default='neutron'),
+    cfg.StrOpt('domain-id', default=None),
+    cfg.StrOpt('format', default=None)
+], group='handler:neutron_floatingip')
+
+
+class NeutronFloatingHandler(BaseAddressHandler):
+    """ Handler for Neutron's notifications """
     __plugin_name__ = 'neutron_floatingip'
 
     def get_exchange_topics(self):
-        exchange = CONF[self.name].control_exchange
+        exchange = cfg.CONF[self.name].control_exchange
 
-        topics = [topic for topic in CONF[self.name].notification_topics]
+        topics = [topic + ".info"
+                  for topic in cfg.CONF[self.name].notification_topics]
 
         return (exchange, topics)
 
@@ -40,35 +50,28 @@ class NeutronFloatingHandler(base.BaseAddressHandler):
             'floatingip.delete.start'
         ]
 
-    def process_notification(self, context, event_type, payload):
+    def process_notification(self, event_type, payload):
         LOG.debug('%s received notification - %s',
                   self.get_canonical_name(), event_type)
 
-        zone_id = CONF[self.name].zone_id
-
-        if not zone_id:
-            LOG.error('NeutronFloatingHandler: zone_id is None, '
-                      'ignore the event.')
-            return
+        # FIXME: Neutron doesn't send ipv in the payload, should maybe
+        # determine this?
+        if event_type not in self.get_event_types():
+            msg = '%s received an invalid event type %s' % (
+                self, event_type)
+            raise ValueError(msg)
 
         if event_type.startswith('floatingip.delete'):
-            self._delete(zone_id=zone_id,
-                         resource_id=payload['floatingip_id'],
+            self._delete(resource_id=payload['floatingip_id'],
                          resource_type='floatingip')
         elif event_type.startswith('floatingip.update'):
             if payload['floatingip']['fixed_ip_address']:
                 address = {
                     'version': 4,
-                    'address': payload['floatingip']['floating_ip_address']
-                }
-                payload['floatingip']['project'] = context.get(
-                             "project_name", None)
-                self._create(addresses=[address],
-                             extra=payload['floatingip'],
-                             zone_id=zone_id,
+                    'address': payload['floatingip']['floating_ip_address']}
+                self._create([address], payload,
                              resource_id=payload['floatingip']['id'],
                              resource_type='floatingip')
-            else:
-                self._delete(zone_id=zone_id,
-                             resource_id=payload['floatingip']['id'],
+            elif not payload['floatingip']['fixed_ip_address']:
+                self._delete(resource_id=payload['floatingip']['id'],
                              resource_type='floatingip')
