@@ -13,24 +13,34 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_log import log as logging
-
-import designate.conf
+from oslo.config import cfg
+from designate.openstack.common import log as logging
 from designate.notification_handler.base import BaseAddressHandler
 
-
-CONF = designate.conf.CONF
 LOG = logging.getLogger(__name__)
 
+cfg.CONF.register_group(cfg.OptGroup(
+    name='handler:nova_fixed',
+    title="Configuration for Nova Notification Handler"
+))
+
+cfg.CONF.register_opts([
+    cfg.ListOpt('notification-topics', default=['monitor']),
+    cfg.StrOpt('control-exchange', default='nova'),
+    cfg.StrOpt('domain-id', default=None),
+    cfg.StrOpt('format', default=None)
+], group='handler:nova_fixed')
+
 
 class NovaFixedHandler(BaseAddressHandler):
-    """Handler for Nova's notifications"""
+    """ Handler for Nova's notifications """
     __plugin_name__ = 'nova_fixed'
 
     def get_exchange_topics(self):
-        exchange = CONF[self.name].control_exchange
+        exchange = cfg.CONF[self.name].control_exchange
 
-        topics = [topic for topic in CONF[self.name].notification_topics]
+        topics = [topic + ".info"
+                  for topic in cfg.CONF[self.name].notification_topics]
 
         return (exchange, topics)
 
@@ -40,29 +50,16 @@ class NovaFixedHandler(BaseAddressHandler):
             'compute.instance.delete.start',
         ]
 
-    def _get_ip_data(self, addr_dict):
-        data = super()._get_ip_data(addr_dict)
-        data['label'] = addr_dict['label']
-        return data
-
-    def process_notification(self, context, event_type, payload):
-        LOG.debug('NovaFixedHandler received notification - %s', event_type)
-
-        zone_id = CONF[self.name].zone_id
-
-        if not zone_id:
-            LOG.error('NovaFixedHandler: zone_id is None, ignore the event.')
-            return
+    def process_notification(self, event_type, payload):
+        LOG.debug('NovaFixedHandler received notification - %s' % event_type)
 
         if event_type == 'compute.instance.create.end':
-            payload['project'] = context.get('project_name', None)
-            self._create(addresses=payload['fixed_ips'],
-                         extra=payload,
-                         zone_id=zone_id,
+            self._create(payload['fixed_ips'], payload,
                          resource_id=payload['instance_id'],
                          resource_type='instance')
 
         elif event_type == 'compute.instance.delete.start':
-            self._delete(zone_id=zone_id,
-                         resource_id=payload['instance_id'],
+            self._delete(resource_id=payload['instance_id'],
                          resource_type='instance')
+        else:
+            raise ValueError('NovaFixedHandler received an invalid event type')
