@@ -14,17 +14,17 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import abc
-
-from oslo_config import cfg
-from oslo_log import log as logging
 from stevedore import driver
 from stevedore import enabled
+from designate.openstack.common import log as logging
+
 
 LOG = logging.getLogger(__name__)
-CONF = cfg.CONF
 
 
-class Plugin(object, metaclass=abc.ABCMeta):
+class Plugin(object):
+    __metaclass__ = abc.ABCMeta
+
     __plugin_ns__ = None
 
     __plugin_name__ = None
@@ -62,7 +62,7 @@ class DriverPlugin(Plugin):
 
     @classmethod
     def get_driver(cls, name):
-        """Load a single driver"""
+        """ Load a single driver """
 
         LOG.debug('Looking for driver %s in %s', name, cls.__plugin_ns__)
 
@@ -81,9 +81,9 @@ class ExtensionPlugin(Plugin):
 
     @classmethod
     def get_extensions(cls, enabled_extensions=None):
-        """Load a series of extensions"""
+        """ Load a series of extensions """
 
-        LOG.debug('Looking for extensions in %s' % cls.__plugin_ns__)
+        LOG.debug('Looking for extensions in %s', cls.__plugin_ns__)
 
         def _check_func(ext):
             if enabled_extensions is None:
