@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -14,39 +14,26 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import abc
-
-from oslo_config import cfg
-
+from oslo.config import cfg
 from designate import exceptions
 from designate.plugin import DriverPlugin
 
 
-class Quota(DriverPlugin, metaclass=abc.ABCMeta):
-    """Base class for quota plugins"""
+class Quota(DriverPlugin):
+    """ Base class for quota plugins """
+    __metaclass__ = abc.ABCMeta
     __plugin_ns__ = 'designate.quota'
     __plugin_type__ = 'quota'
 
     def limit_check(self, context, tenant_id, **values):
-        resources_exceeded = []
         quotas = self.get_quotas(context, tenant_id)
 
         for resource, value in values.items():
             if resource in quotas:
-                # Setting the resource quota to a negative value will make
-                # the resource unlimited
-                if quotas[resource] >= 0 and value > quotas[resource]:
-                    resources_exceeded.append(resource)
+                if value >= quotas[resource]:
+                    raise exceptions.OverQuota()
             else:
-                raise exceptions.QuotaResourceUnknown(
-                    "'%s' is not a valid quota resource." % resource
-                )
-
-        if resources_exceeded:
-            resources_exceeded.sort(key=len)
-            raise exceptions.OverQuota(
-                'Quota exceeded for %s.' %
-                ', '.join(resources_exceeded)
-            )
+                raise exceptions.QuotaResourceUnknown()
 
     def get_quotas(self, context, tenant_id):
         quotas = self.get_default_quotas(context)
@@ -61,19 +48,17 @@ class Quota(DriverPlugin, metaclass=abc.ABCMeta):
 
     def get_default_quotas(self, context):
         return {
-            'zones': cfg.CONF.quota_zones,
-            'zone_recordsets': cfg.CONF.quota_zone_recordsets,
-            'zone_records': cfg.CONF.quota_zone_records,
+            'domains': cfg.CONF.quota_domains,
+            'domain_recordsets': cfg.CONF.quota_domain_recordsets,
+            'domain_records': cfg.CONF.quota_domain_records,
             'recordset_records': cfg.CONF.quota_recordset_records,
-            'api_export_size': cfg.CONF.quota_api_export_size,
         }
 
     def get_quota(self, context, tenant_id, resource):
         quotas = self._get_quotas(context, tenant_id)
 
         if resource not in quotas:
-            raise exceptions.QuotaResourceUnknown("%s is not a valid quota "
-                                                  "resource" % resource)
+            raise exceptions.QuotaResourceUnknown()
 
         return quotas[resource]
 
