@@ -1,6 +1,6 @@
 # Copyright 2012 Hewlett-Packard Development Company, L.P. All Rights Reserved.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -13,30 +13,15 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_config import cfg
+from oslo.config import cfg
 
-sink_group = cfg.OptGroup(
+cfg.CONF.register_group(cfg.OptGroup(
     name='service:sink', title="Configuration for Sink Service"
-)
+))
 
-OPTS = [
-    cfg.IntOpt('workers',
-               help='Number of sink worker processes to spawn'),
-    cfg.IntOpt('threads', default=1000,
-               help='Number of sink greenthreads to spawn'),
+cfg.CONF.register_opts([
+    cfg.IntOpt('workers', default=None,
+               help='Number of worker processes to spawn'),
     cfg.ListOpt('enabled-notification-handlers', default=[],
                 help='Enabled Notification Handlers'),
-    cfg.StrOpt('listener-pool-name',
-               help='pool name to use for oslo.messaging '
-               'notification listener. '
-               'Note that listener pooling is not supported '
-               'by all oslo.messaging drivers.'),
-]
-
-
-cfg.CONF.register_group(sink_group)
-cfg.CONF.register_opts(OPTS, group=sink_group)
-
-
-def list_opts():
-    yield sink_group, OPTS
+], group='service:sink')
