@@ -14,35 +14,97 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from unittest import mock
-
-from oslo_config import cfg
-from oslo_messaging.notify import notifier
-
 from designate.tests.test_api import ApiTestCase
-from designate import context
 from designate import exceptions
-from designate import rpc
 from designate.api import middleware
 
 
+class FakeContext(object):
+    def __init__(self, roles=[]):
+        self.roles = roles
+
+
 class FakeRequest(object):
     def __init__(self):
         self.headers = {}
         self.environ = {}
-        self.GET = {}
-        self.POST = {}
-
-    @property
-    def params(self):
-        data = self.GET.copy()
-        data.update(self.POST)
-        return data
 
     def get_response(self, app):
         return "FakeResponse"
 
 
+class MaintenanceMiddlewareTest(ApiTestCase):
+    def test_process_request_disabled(self):
+        self.config(maintenance_mode=False, group='service:api')
+
+        request = FakeRequest()
+        app = middleware.MaintenanceMiddleware({})
+
+        # Process the request
+        response = app(request)
+
+        # Ensure request was not blocked
+        self.assertEqual(response, 'FakeResponse')
+
+    def test_process_request_enabled_reject(self):
+        self.config(maintenance_mode=True, maintenance_mode_role='admin',
+                    group='service:api')
+
+        request = FakeRequest()
+        request.environ['context'] = FakeContext(roles=['user'])
+
+        app = middleware.MaintenanceMiddleware({})
+
+        # Process the request
+        response = app(request)
+
+        # Ensure request was blocked
+        self.assertEqual(response.status_code, 503)
+
+    def test_process_request_enabled_reject_no_roles(self):
+        self.config(maintenance_mode=True, maintenance_mode_role='admin',
+                    group='service:api')
+
+        request = FakeRequest()
+        request.environ['context'] = FakeContext(roles=[])
+
+        app = middleware.MaintenanceMiddleware({})
+
+        # Process the request
+        response = app(request)
+
+        # Ensure request was blocked
+        self.assertEqual(response.status_code, 503)
+
+    def test_process_request_enabled_reject_no_context(self):
+        self.config(maintenance_mode=True, maintenance_mode_role='admin',
+                    group='service:api')
+
+        request = FakeRequest()
+        app = middleware.MaintenanceMiddleware({})
+
+        # Process the request
+        response = app(request)
+
+        # Ensure request was blocked
+        self.assertEqual(response.status_code, 503)
+
+    def test_process_request_enabled_bypass(self):
+        self.config(maintenance_mode=True, maintenance_mode_role='admin',
+                    group='service:api')
+
+        request = FakeRequest()
+        request.environ['context'] = FakeContext(roles=['admin'])
+
+        app = middleware.MaintenanceMiddleware({})
+
+        # Process the request
+        response = app(request)
+
+        # Ensure request was not blocked
+        self.assertEqual(response, 'FakeResponse')
+
+
 class KeystoneContextMiddlewareTest(ApiTestCase):
     def test_process_request(self):
         app = middleware.KeystoneContextMiddleware({})
@@ -66,7 +128,7 @@ class KeystoneContextMiddlewareTest(ApiTestCase):
         self.assertFalse(context.is_admin)
         self.assertEqual('AuthToken', context.auth_token)
         self.assertEqual('UserID', context.user_id)
-        self.assertEqual('TenantID', context.project_id)
+        self.assertEqual('TenantID', context.tenant_id)
         self.assertEqual(['admin', 'Member'], context.roles)
 
     def test_process_request_invalid_keystone_token(self):
@@ -85,25 +147,7 @@ class KeystoneContextMiddlewareTest(ApiTestCase):
         # Process the request
         response = app(request)
 
-        self.assertEqual(401, response.status_code)
-
-    def test_process_unscoped_token(self):
-        app = middleware.KeystoneContextMiddleware({})
-
-        request = FakeRequest()
-
-        request.headers = {
-            'X-Auth-Token': 'AuthToken',
-            'X-User-ID': 'UserID',
-            'X-Tenant-ID': None,
-            'X-Roles': 'admin,Member',
-        }
-
-        # Process the request
-        response = app(request)
-
-        # Ensure request was not blocked
-        self.assertEqual(response, 'FakeResponse')
+        self.assertEqual(response.status_code, 401)
 
 
 class NoAuthContextMiddlewareTest(ApiTestCase):
@@ -117,133 +161,38 @@ class NoAuthContextMiddlewareTest(ApiTestCase):
 
         self.assertIn('context', request.environ)
 
-        ctxt = request.environ['context']
+        context = request.environ['context']
 
-        self.assertIsNone(ctxt.auth_token)
-        self.assertEqual('noauth-user', ctxt.user_id)
-        self.assertEqual('noauth-project', ctxt.project_id)
-        self.assertEqual(['admin'], ctxt.roles)
-
-
-class MaintenanceMiddlewareTest(ApiTestCase):
-    def test_process_request_disabled(self):
-        self.config(maintenance_mode=False, group='service:api')
-
-        request = FakeRequest()
-        app = middleware.MaintenanceMiddleware({})
-
-        # Process the request
-        response = app(request)
-
-        # Ensure request was not blocked
-        self.assertEqual(response, 'FakeResponse')
-
-    def test_process_request_enabled_reject(self):
-        self.config(maintenance_mode=True, maintenance_mode_role='admin',
-                    group='service:api')
-
-        request = FakeRequest()
-        request.environ['context'] = context.DesignateContext(roles=['user'])
-
-        app = middleware.MaintenanceMiddleware({})
-
-        # Process the request
-        response = app(request)
-
-        # Ensure request was blocked
-        self.assertEqual(503, response.status_code)
-
-    def test_process_request_enabled_reject_no_roles(self):
-        self.config(maintenance_mode=True, maintenance_mode_role='admin',
-                    group='service:api')
-
-        request = FakeRequest()
-        request.environ['context'] = context.DesignateContext(roles=[])
-
-        app = middleware.MaintenanceMiddleware({})
-
-        # Process the request
-        response = app(request)
-
-        # Ensure request was blocked
-        self.assertEqual(503, response.status_code)
-
-    def test_process_request_enabled_reject_no_context(self):
-        self.config(maintenance_mode=True, maintenance_mode_role='admin',
-                    group='service:api')
-
-        request = FakeRequest()
-        app = middleware.MaintenanceMiddleware({})
-
-        # Process the request
-        response = app(request)
-
-        # Ensure request was blocked
-        self.assertEqual(503, response.status_code)
-
-    def test_process_request_enabled_bypass(self):
-        self.config(maintenance_mode=True, maintenance_mode_role='admin',
-                    group='service:api')
-
-        request = FakeRequest()
-        request.environ['context'] = context.DesignateContext(roles=['admin'])
-
-        app = middleware.MaintenanceMiddleware({})
-
-        # Process the request
-        response = app(request)
-
-        # Ensure request was not blocked
-        self.assertEqual('FakeResponse', response)
-
-
-class NormalizeURIMiddlewareTest(ApiTestCase):
-    def test_strip_trailing_slases(self):
-        request = FakeRequest()
-        request.environ['PATH_INFO'] = 'resource/'
-
-        app = middleware.NormalizeURIMiddleware({})
-
-        # Process the request
-        app(request)
-
-        # Ensure request's PATH_INFO had the trailing slash removed.
-        self.assertEqual('resource', request.environ['PATH_INFO'])
-
-    def test_strip_trailing_slases_multiple(self):
-        request = FakeRequest()
-        request.environ['PATH_INFO'] = 'resource///'
-
-        app = middleware.NormalizeURIMiddleware({})
-
-        # Process the request
-        app(request)
-
-        # Ensure request's PATH_INFO had the trailing slash removed.
-        self.assertEqual('resource', request.environ['PATH_INFO'])
+        self.assertTrue(context.is_admin)
+        self.assertIsNone(context.auth_token)
+        self.assertEqual('noauth-user', context.user_id)
+        self.assertEqual('noauth-project', context.tenant_id)
+        self.assertEqual([], context.roles)
 
 
 class FaultMiddlewareTest(ApiTestCase):
-    @mock.patch.object(notifier.Notifier, "error")
-    def test_notify_of_fault(self, mock_notifier):
+    __test__ = True
+
+    def test_notify_of_fault(self):
         self.config(notify_api_faults=True)
-        rpc.init(cfg.CONF)
         app = middleware.FaultWrapperMiddleware({})
 
         class RaisingRequest(FakeRequest):
             def get_response(self, request):
-                raise exceptions.DuplicateZone()
+                raise exceptions.DuplicateDomain()
 
         request = RaisingRequest()
-        ctxt = context.DesignateContext()
-        ctxt.request_id = 'one'
-        request.environ['context'] = ctxt
+        context = FakeContext()
+        context.request_id = 'one'
+        request.environ['context'] = context
 
         # Process the request
         app(request)
 
-        self.assertEqual(1, mock_notifier.call_count)
-        mock_notifier.call_args(
-            ctxt,
-            'dns.api.fault',
-            {"url": None, "status": 409, "exception": ""})
+        notifications = self.get_notifications()
+        self.assertEqual(1, len(notifications))
+
+        self.assertEqual('ERROR', notifications[0]['priority'])
+        self.assertEqual('dns.api.fault', notifications[0]['event_type'])
+        self.assertIn('timestamp', notifications[0])
+        self.assertIn('publisher_id', notifications[0])
