@@ -13,13 +13,6 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from unittest import mock
-
-
-from paste import urlmap
-
-from designate.api import service
-from designate import exceptions
 from designate.tests.test_api import ApiTestCase
 
 
@@ -27,22 +20,11 @@ class ApiServiceTest(ApiTestCase):
     def setUp(self):
         super(ApiServiceTest, self).setUp()
 
-        self.config(listen=['0.0.0.0:0'], group='service:api')
+        # Use a random port for the API
+        self.config(api_port=0, group='service:api')
 
-        self.service = service.Service()
+        self.service = self.start_service('api')
 
     def test_start_and_stop(self):
         # NOTE: Start is already done by the fixture in start_service()
-        self.service.start()
         self.service.stop()
-
-    def test_get_wsgi_application(self):
-        self.assertIsInstance(self.service.wsgi_application, urlmap.URLMap)
-
-    @mock.patch('designate.utils.find_config')
-    def test_unable_to_find_config(self, mock_find_config):
-        mock_find_config.return_value = list()
-        with self.assertRaisesRegex(
-                exceptions.ConfigurationError,
-                'Unable to determine appropriate api-paste-config file'):
-            self.assertFalse(self.service.wsgi_application)
