@@ -14,12 +14,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import itertools
-
-from oslo_log import log as logging
 from webtest import TestApp
-
-from designate.api import middleware
+from designate.openstack.common import log as logging
 from designate.api import v2 as api_v2
+from designate.api import middleware
 from designate.tests.test_api import ApiTestCase
 
 
@@ -37,26 +35,26 @@ class ApiV2TestCase(ApiTestCase):
     def setUp(self):
         super(ApiV2TestCase, self).setUp()
 
+        # Ensure the v2 API is enabled
+        self.config(enable_api_v2=True, group='service:api')
+
         # Create the application
         self.app = api_v2.factory({})
 
-        # Inject the NormalizeURIMiddleware middleware
-        self.app = middleware.NormalizeURIMiddleware(self.app)
-
-        # Inject the ValidationError middleware
-        self.app = middleware.APIv2ValidationErrorMiddleware(self.app)
-
         # Inject the FaultWrapper middleware
         self.app = middleware.FaultWrapperMiddleware(self.app)
 
         # Inject the TestContext middleware
         self.app = middleware.TestContextMiddleware(
-            self.app, self.admin_context.project_id,
-            self.admin_context.project_id)
+            self.app, self.admin_context.tenant_id,
+            self.admin_context.tenant_id)
 
         # Obtain a test client
         self.client = TestApp(self.app)
 
+        # Create and start an instance of the central service
+        self.central_service = self.start_service('central')
+
     def tearDown(self):
         self.app = None
         self.client = None
@@ -138,7 +136,7 @@ class ApiV2TestCase(ApiTestCase):
 
         x = 0
         length = len(data)
-        for i in range(0, length):
+        for i in xrange(0, length):
             assert data[i]['id'] == response[x]['id']
 
             x += 1
