@@ -13,13 +13,11 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+import json
 import os
-
-from oslo_serialization import jsonutils
-
+import testtools
 from designate.tests import resources
 
-
 FIXTURES_PATH = os.path.join(resources.path, 'sample_notifications')
 
 
@@ -30,7 +28,15 @@ class NotificationHandlerMixin(object):
         if not os.path.exists(filename):
             raise Exception('Invalid notification fixture requested')
 
-        with open(filename, 'r') as fp:
-            fixture = fp.read()
+        with open(filename, 'r') as fh:
+            return json.load(fh)
 
-        return jsonutils.loads(fixture)
+    def test_invalid_event_type(self):
+        if not hasattr(self, 'plugin'):
+            raise NotImplementedError
+        event_type = 'invalid'
+
+        self.assertNotIn(event_type, self.plugin.get_event_types())
+
+        with testtools.ExpectedException(ValueError):
+            self.plugin.process_notification(event_type, 'payload')
